***************************************
Fundoshi: Simple, lean, mean manga API.
***************************************

Fundoshi provides a consistent Python API to extract data from various online
manga reader sites.

=============
Documentation
=============

http://fundoshi.nerdyweekly.com/

=======
License
=======

Fundoshi is released under the MIT license. See `LICENSE`.
